=========
Changelog
=========

Version 0.0.5
=============

- Added method to make it easier to get data

Version 0.0.4
=============

- Simplified setup of regions and performace assessment models

Version 0.0.2
=============

- Basic functionallity to setup and run projects

Version 0.0.3
=============

- Added functionallity to convert dynamind files to json and back

Version 0.0.1
=============

- Basic functionallity to login and create projects
- Inital commit




